@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -23,7 +25,7 @@ inline
 uvec
 trimatu_ind(const SizeMat& s, const sword k = 0)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword n_rows = s.n_rows;
   const uword n_cols = s.n_cols;
@@ -31,7 +33,7 @@ trimatu_ind(const SizeMat& s, const sword k = 0)
   const uword row_offset = (k < 0) ? uword(-k) : uword(0);
   const uword col_offset = (k > 0) ? uword( k) : uword(0);
   
-  arma_debug_check_bounds( ((row_offset > 0) && (row_offset >= n_rows)) || ((col_offset > 0) && (col_offset >= n_cols)), "trimatu_ind(): requested diagonal is out of bounds" );
+  arma_conform_check_bounds( ((row_offset > 0) && (row_offset >= n_rows)) || ((col_offset > 0) && (col_offset >= n_cols)), "trimatu_ind(): requested diagonal is out of bounds" );
   
   const uword N = (std::min)(n_rows - row_offset, n_cols - col_offset);
   
@@ -84,7 +86,7 @@ inline
 uvec
 trimatl_ind(const SizeMat& s, const sword k = 0)
   {
-  arma_extra_debug_sigprint();
+  arma_debug_sigprint();
   
   const uword n_rows = s.n_rows;
   const uword n_cols = s.n_cols;
@@ -92,7 +94,7 @@ trimatl_ind(const SizeMat& s, const sword k = 0)
   const uword row_offset = (k < 0) ? uword(-k) : uword(0);
   const uword col_offset = (k > 0) ? uword( k) : uword(0);
   
-  arma_debug_check_bounds( ((row_offset > 0) && (row_offset >= n_rows)) || ((col_offset > 0) && (col_offset >= n_cols)), "trimatl_ind(): requested diagonal is out of bounds" );
+  arma_conform_check_bounds( ((row_offset > 0) && (row_offset >= n_rows)) || ((col_offset > 0) && (col_offset >= n_cols)), "trimatl_ind(): requested diagonal is out of bounds" );
   
   const uword N = (std::min)(n_rows - row_offset, n_cols - col_offset);
   
